# Formaloo SDK

This is a free SDK for using the API of Formaloo Customer Data Platform.

Formaloo is the next generation of data analytics. With Formaloo you can Use your own data to analyze your customers, your business and even predict the future. Formaloo adds an AI-powered data expert to SMBs & SMEs so they can really understand their business and their customers and act on it to boost their Loyalty, LTV and CX.

Formaloo is built for businesses, not data scientists. It's super simple to use and understand, you don't have to know data analytics or coding and best of all, it requires no data experts to operate it.

Formaloo CDP is a Customer Data Platform that collects, analyzes, and unifies data from all data sources in order to grow customers' loyalty.

Formaloo is a business productivity solution built to transform the way people collect information and put it to work.
Formaloo solutions such as Formaloo CDP, Data Collection (Database & Form builder), Formaloo DataFlow, Data Analysis tool, Workflow Automation helps thousands of businesses every day to collect & manage their data with impact.
